@@ -35,6 +35,7 @@ function InsertBlockItem(guiAction) {
     this.docItem = undefined;
 
     this.blockName = undefined;
+    // set to flatten all entities to this one layer:
     this.layerName = undefined;
     this.offset = undefined;
     this.scale = 1.0;
@@ -124,7 +125,7 @@ InsertBlockItem.prototype.beginEvent = function() {
         while (isNull(this.blockName) || doc.hasBlock(this.blockName)) {
             this.blockName = 'block_' + c++;
         }
-        EAction.handleUserMessage(qsTr("Adjusted invalid block name to '%1'").arg(this.blockName));
+        EAction.handleUserMessage(qsTr("Adjusted invalid block name to \"%1\"").arg(this.blockName));
     }
 
     if (this.docItem.hasBlock(this.blockName)) {
