@@ -275,27 +275,46 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
 
 DefaultAction.prototype.mouseReleaseEvent = function(event) {
     var persistentSelection = RSettings.getBoolValue("GraphicsView/PersistentSelection", false);
-    var view, range, strictRange, entityId;
+    var entityId;
 
-    var shiftPressed = (event.modifiers() & Qt.ShiftModifier) > 0 || (event.modifiers() & Qt.ControlModifier) > 0 || persistentSelection===true;
+    var shiftPressed = this.isShiftPressed(event) || (event.modifiers() & Qt.ControlModifier) > 0 || persistentSelection===true;
+    var addToSelection = this.getAddToSelection(shiftPressed);
 
     if (event.button() === Qt.LeftButton) {
         switch (this.state) {
         case DefaultAction.State.Dragging:
+
+            // handle clicks on reference points:
+            this.d2Model = event.getModelPosition();
+            this.d2Screen = event.getScreenPosition();
+            var view = event.getGraphicsView();
+            if (this.d1Screen.equalsFuzzy(this.d2Screen, 10)) {
+                // mouse press and release at same position (click):
+                var referencePoint = view.getClosestReferencePoint(this.d1Screen, this.minPickRangePixels);
+                if (referencePoint.isValid() && !referencePoint.isIgnore() && !RSettings.getIgnoreAllReferencePoints()) {
+                    this.d1Model = referencePoint;
+                    var op = new RClickReferencePointOperation(this.d1Model);
+                    this.di.applyOperation(op);
+                    this.setState(DefaultAction.State.Neutral);
+                    return;
+                }
+            }
+
+
             // find selectable entity under cursor:
             entityId = this.getEntityId(event, false, true);
 
             //qDebug("entityId: ", entityId);
 
             if (entityId !== -1) {
-                if (shiftPressed && this.document.isSelected(entityId)) {
+                if (addToSelection && this.document.isSelected(entityId)) {
                     this.deselectEntity(entityId);
                 }
                 else {
-                    this.selectEntity(entityId, shiftPressed);
+                    this.selectEntity(entityId, addToSelection);
                 }
             } else {
-                if (!shiftPressed) {
+                if (!addToSelection) {
                     if (persistentSelection===false) {
                         this.di.clearSelection();
                     }
@@ -310,7 +329,7 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
             this.di.clearPreview();
             this.d2Model = event.getModelPosition();
 
-            if ((event.modifiers().valueOf() == Qt.ShiftModifier.valueOf()) ||
+            if (addToSelection ||
                 (event.modifiers().valueOf() == Qt.ControlModifier.valueOf()) ||
                 persistentSelection===true) {
 
@@ -361,7 +380,7 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
 
                 // use right-click on entity to select entity:
                 else if (rightClickToDeselect) {
-                    this.selectEntity(entityId, shiftPressed);
+                    this.selectEntity(entityId, addToSelection);
                     handled = true;
                 }
             }
@@ -435,7 +454,8 @@ DefaultAction.prototype.escapeEvent = function(event) {
 DefaultAction.prototype.pickCoordinate = function(event, preview) {
     var op;
 
-    var shiftPressed = (event.getModifiers() & Qt.ShiftModifier) > 0;
+    var shiftPressed = this.isShiftPressed(event);
+    var addToSelection = this.getAddToSelection(shiftPressed);
     var doc = this.getDocument();
 
     switch (this.state) {
@@ -649,7 +669,7 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
             // block editing with double click might be disabled for this entity:
             if (entity.getCustomBoolProperty("QCAD", "DoubleClickEditBlock", true)===true) {
                 include("scripts/Block/Block.js");
-                EAction.handleUserMessage(qsTr("Editing block '%1'<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()), false);
+                EAction.handleUserMessage(qsTr("Editing block \"%1\"<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()), false);
                 Block.editBlock(this.di, entity.getReferencedBlockName());
             }
         }
@@ -669,7 +689,7 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
             var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
-            var add = (event.modifiers().valueOf() === Qt.ShiftModifier.valueOf());
+            var add = this.isShiftPressed(event);
             if (entity.isSelected()) {
                 this.di.selectEntities(matchingEntityIds, add);
             }
@@ -684,3 +704,25 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 //        this.di.setCurrentViewport(entity.data());
 //    }
 };
+
+/**
+ * \return True if the shift key is pressed to alter the function (e.g. add to selection).
+ */
+DefaultAction.prototype.isShiftPressed = function(event) {
+    if (isFunction(event.getModifiers)) {
+        return (event.getModifiers() & Qt.ShiftModifier) > 0;
+    }
+    if (isFunction(event.modifiers)) {
+        return (event.modifiers().valueOf() === Qt.ShiftModifier.valueOf());
+    }
+    return false;
+};
+
+/**
+ * \return True to add to selection (by default this is when shiftPressed is true).
+ * May be reimplemented to allow other ways to add to selection (e.g. user interface button, etc.)
+ */
+DefaultAction.prototype.getAddToSelection = function(shiftPressed) {
+    return shiftPressed;
+};
+
