@@ -1138,13 +1138,14 @@ WidgetFactory.initLayerCombo = function(comboBox, doc) {
     }
 
     comboBox.clear();
-    comboBox.iconSize = new QSize(32, 16);
+    comboBox.iconSize = new QSize(16, 10);
     var names = doc.getLayerNames();
+    //names = RS.sortAlphanumerical(names);
     names.sort(Array.alphaNumericalSorter);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
-        var icon = RColor.getIcon(layer.getColor());
+        var icon = RColor.getIcon(layer.getColor(), new QSize(comboBox.iconSize.width(),10));
         comboBox.addItem(icon, layer.getName());
     }
 };
@@ -1160,6 +1161,7 @@ WidgetFactory.initBlockCombo = function(comboBox, doc, showSpaces) {
     comboBox.clear();
     var names = doc.getBlockNames();
     names.sort(Array.alphaNumericalSorter);
+    //names = RS.sortAlphanumerical(names);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         if (showSpaces || !name.startsWith("*")) {
